# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_stubs/modbus_iface.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgrpc_stubs/modbus_iface.proto\x12\x0cmodbus_iface\"\xd5\x01\n\tbusStatus\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\x08\x12=\n\x0fserial_settings\x18\x03 \x01(\x0b\x32\x1f.modbus_iface.serialBusSettingsH\x00\x88\x01\x01\x12\x41\n\x11\x65thernet_settings\x18\x04 \x01(\x0b\x32!.modbus_iface.ethernetBusSettingsH\x01\x88\x01\x01\x42\x12\n\x10_serial_settingsB\x14\n\x12_ethernet_settings\"\xb0\x01\n\x0eresponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\rresponse_code\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1d\n\x10response_message\x18\x03 \x01(\tH\x01\x88\x01\x01\x12+\n\nbus_status\x18\x04 \x03(\x0b\x32\x17.modbus_iface.busStatusB\x10\n\x0e_response_codeB\x13\n\x11_response_message\"#\n\x10testCommsRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\"\\\n\x11testCommsResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x10\n\x08response\x18\x02 \x01(\t\"\xeb\x01\n\x11serialBusSettings\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61ud\x18\x02 \x01(\x05\x12\x1a\n\rmodbus_method\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdata_bits\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x13\n\x06parity\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tstop_bits\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12\x14\n\x07timeout\x18\x07 \x01(\x02H\x04\x88\x01\x01\x42\x10\n\x0e_modbus_methodB\x0c\n\n_data_bitsB\t\n\x07_parityB\x0c\n\n_stop_bitsB\n\n\x08_timeout\"\x7f\n\x13\x65thernetBusSettings\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x1a\n\rmodbus_method\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07timeout\x18\x04 \x01(\x02H\x01\x88\x01\x01\x42\x10\n\x0e_modbus_methodB\n\n\x08_timeout\"\xac\x01\n\x0eopenBusRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12:\n\x0fserial_settings\x18\x02 \x01(\x0b\x32\x1f.modbus_iface.serialBusSettingsH\x00\x12>\n\x11\x65thernet_settings\x18\x03 \x01(\x0b\x32!.modbus_iface.ethernetBusSettingsH\x00\x42\x0e\n\x0c\x62us_settings\"X\n\x0fopenBusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\"\x10\n\x0elistBusRequest\"u\n\x0flistBusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12+\n\nbus_status\x18\x02 \x03(\x0b\x32\x17.modbus_iface.busStatus\"\"\n\x10\x62usStatusRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\"w\n\x11\x62usStatusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12+\n\nbus_status\x18\x02 \x01(\x0b\x32\x17.modbus_iface.busStatus\"!\n\x0f\x63loseBusRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\"Y\n\x10\x63loseBusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\"o\n\x13readRegisterRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x11\n\tmodbus_id\x18\x02 \x01(\x05\x12\x15\n\rregister_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\x05\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\"t\n\x14readRegisterResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x15\n\rresponse_code\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x05\"q\n\x14writeRegisterRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x11\n\tmodbus_id\x18\x02 \x01(\x05\x12\x15\n\rregister_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\x05\x12\x0e\n\x06values\x18\x05 \x03(\x05\"e\n\x15writeRegisterResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x15\n\rresponse_code\x18\x02 \x01(\x05\"z\n\x1cscheduleWriteRegisterRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x15\n\rregister_type\x18\x02 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x05\x12\x12\n\ndelay_secs\x18\x05 \x01(\x05\"z\n\x1dscheduleWriteRegisterResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\x12\x12\n\ndelay_secs\x18\x03 \x01(\x05\"\x8e\x01\n\x1freadRegisterSubscriptionRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x11\n\tmodbus_id\x18\x02 \x01(\x05\x12\x15\n\rregister_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\x05\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x11\n\tpoll_secs\x18\x06 \x01(\x05\"\x90\x01\n readRegisterSubscriptionResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\x12\x15\n\rresponse_code\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x05\x32\xb9\x06\n\x0bmodbusIface\x12N\n\ttestComms\x12\x1e.modbus_iface.testCommsRequest\x1a\x1f.modbus_iface.testCommsResponse\"\x00\x12H\n\x07openBus\x12\x1c.modbus_iface.openBusRequest\x1a\x1d.modbus_iface.openBusResponse\"\x00\x12H\n\x07listBus\x12\x1c.modbus_iface.listBusRequest\x1a\x1d.modbus_iface.listBusResponse\"\x00\x12N\n\tbusStatus\x12\x1e.modbus_iface.busStatusRequest\x1a\x1f.modbus_iface.busStatusResponse\"\x00\x12K\n\x08\x63loseBus\x12\x1d.modbus_iface.closeBusRequest\x1a\x1e.modbus_iface.closeBusResponse\"\x00\x12X\n\rreadRegisters\x12!.modbus_iface.readRegisterRequest\x1a\".modbus_iface.readRegisterResponse\"\x00\x12[\n\x0ewriteRegisters\x12\".modbus_iface.writeRegisterRequest\x1a#.modbus_iface.writeRegisterResponse\"\x00\x12s\n\x16scheduleWriteRegisters\x12*.modbus_iface.scheduleWriteRegisterRequest\x1a+.modbus_iface.scheduleWriteRegisterResponse\"\x00\x12}\n\x18readRegisterSubscription\x12-.modbus_iface.readRegisterSubscriptionRequest\x1a..modbus_iface.readRegisterSubscriptionResponse\"\x00\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_stubs.modbus_iface_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BUSSTATUS']._serialized_start=48
  _globals['_BUSSTATUS']._serialized_end=261
  _globals['_RESPONSEHEADER']._serialized_start=264
  _globals['_RESPONSEHEADER']._serialized_end=440
  _globals['_TESTCOMMSREQUEST']._serialized_start=442
  _globals['_TESTCOMMSREQUEST']._serialized_end=477
  _globals['_TESTCOMMSRESPONSE']._serialized_start=479
  _globals['_TESTCOMMSRESPONSE']._serialized_end=571
  _globals['_SERIALBUSSETTINGS']._serialized_start=574
  _globals['_SERIALBUSSETTINGS']._serialized_end=809
  _globals['_ETHERNETBUSSETTINGS']._serialized_start=811
  _globals['_ETHERNETBUSSETTINGS']._serialized_end=938
  _globals['_OPENBUSREQUEST']._serialized_start=941
  _globals['_OPENBUSREQUEST']._serialized_end=1113
  _globals['_OPENBUSRESPONSE']._serialized_start=1115
  _globals['_OPENBUSRESPONSE']._serialized_end=1203
  _globals['_LISTBUSREQUEST']._serialized_start=1205
  _globals['_LISTBUSREQUEST']._serialized_end=1221
  _globals['_LISTBUSRESPONSE']._serialized_start=1223
  _globals['_LISTBUSRESPONSE']._serialized_end=1340
  _globals['_BUSSTATUSREQUEST']._serialized_start=1342
  _globals['_BUSSTATUSREQUEST']._serialized_end=1376
  _globals['_BUSSTATUSRESPONSE']._serialized_start=1378
  _globals['_BUSSTATUSRESPONSE']._serialized_end=1497
  _globals['_CLOSEBUSREQUEST']._serialized_start=1499
  _globals['_CLOSEBUSREQUEST']._serialized_end=1532
  _globals['_CLOSEBUSRESPONSE']._serialized_start=1534
  _globals['_CLOSEBUSRESPONSE']._serialized_end=1623
  _globals['_READREGISTERREQUEST']._serialized_start=1625
  _globals['_READREGISTERREQUEST']._serialized_end=1736
  _globals['_READREGISTERRESPONSE']._serialized_start=1738
  _globals['_READREGISTERRESPONSE']._serialized_end=1854
  _globals['_WRITEREGISTERREQUEST']._serialized_start=1856
  _globals['_WRITEREGISTERREQUEST']._serialized_end=1969
  _globals['_WRITEREGISTERRESPONSE']._serialized_start=1971
  _globals['_WRITEREGISTERRESPONSE']._serialized_end=2072
  _globals['_SCHEDULEWRITEREGISTERREQUEST']._serialized_start=2074
  _globals['_SCHEDULEWRITEREGISTERREQUEST']._serialized_end=2196
  _globals['_SCHEDULEWRITEREGISTERRESPONSE']._serialized_start=2198
  _globals['_SCHEDULEWRITEREGISTERRESPONSE']._serialized_end=2320
  _globals['_READREGISTERSUBSCRIPTIONREQUEST']._serialized_start=2323
  _globals['_READREGISTERSUBSCRIPTIONREQUEST']._serialized_end=2465
  _globals['_READREGISTERSUBSCRIPTIONRESPONSE']._serialized_start=2468
  _globals['_READREGISTERSUBSCRIPTIONRESPONSE']._serialized_end=2612
  _globals['_MODBUSIFACE']._serialized_start=2615
  _globals['_MODBUSIFACE']._serialized_end=3440
# @@protoc_insertion_point(module_scope)
